#!/bin/sh

if [ $# -lt 3 -o "$1" = "-h" -o "$1" = "--help" ]; then
	echo "Usage: $0 <hatari> <program> <cpulevel> ..."
	exit 1;
fi

hatari="$1"
shift
if [ ! -x "$hatari" ]; then
	echo "First parameter must point to valid hatari executable."
	exit 1;
fi;

program="$1"
shift
if [ ! -f "$program" ]; then
	echo "Second parameter must point to valid gemdos executable."
	exit 1;
fi;

cpulevel="$1"
shift
if [ -z "$cpulevel" -o "$cpulevel" -lt 0 -o "$cpulevel" -gt 4 ]; then
	echo "Third parameter must be cpulevel in range 0..4."
	exit 1;
fi;

basedir=$(dirname $0)
testdir=$(mktemp -d)

remove_temp() {
  if test "$program" != test-inf.ttp; then rm -rf "$testdir"; fi
}
trap remove_temp EXIT

export SDL_VIDEODRIVER=dummy
export SDL_AUDIODRIVER=dummy

echo HOME="$testdir" "$hatari" --log-level debug --sound off --cpuclock 32 \
	--tos none -d "$testdir" --run-vbls 500 --bios-intercept on --cpulevel "$cpulevel" "$@" "$basedir/$program" \
	> "$testdir/out.txt"
HOME="$testdir" "$hatari" --log-level debug --sound off --cpuclock 32 \
	--tos none -d "$testdir" --run-vbls 500 --bios-intercept on --cpulevel "$cpulevel" "$@" "$basedir/$program" \
	2>> "$testdir/out.txt"
exitstat=$?
if [ $exitstat -ne 0 ]; then
	echo "Running hatari failed. Status=${exitstat}."
	cat "$testdir/out.txt"
	exit 1
fi

echo "Test PASSED."
exit 0
